@@ -86,8 +86,11 @@ wmax <- function(p, na.rm=FALSE) {
 
 
 setMethod("extract", signature(x="SpatRaster", y="SpatVector"), 
-function(x, y, fun=NULL, method="simple", list=FALSE, factors=TRUE, cells=FALSE, xy=FALSE, weights=FALSE, exact=FALSE, touches=is.lines(y), ...) { 
-	method = match.arg(tolower(method), c("simple", "bilinear"))
+function(x, y, fun=NULL, method="simple", list=FALSE, factors=TRUE, cells=FALSE, xy=FALSE, weights=FALSE, exact=FALSE, touches=is.lines(y), layer=NULL, ...) { 
+
+	nl <- nlyr(x)
+	useLyr <- FALSE
+	method <- match.arg(tolower(method), c("simple", "bilinear"))
 	hasfun <- !is.null(fun)
 	if (weights && exact) {
 		exact = FALSE
@@ -117,6 +120,25 @@ function(x, y, fun=NULL, method="simple", list=FALSE, factors=TRUE, cells=FALSE,
 			if (bad) error("extract", 'if weights or exact=TRUE, "fun" must be "sum", "mean" or NULL')
 		}
 	} 
+	if (!is.null(layer) && nl > 1) {
+		if (any(is.na(layer))) {error("extract", "argument 'layer' cannot have NAs")}
+		if (length(layer) == 1) {
+			lyr_name <- layer
+			layer <- as.character(y[[layer,drop=TRUE]])
+		} else {
+			lyr_name <- "layer"
+			stopifnot(length(layer) == nrow(y))
+		}
+		if (is.numeric(layer)) {
+			layer <- round(layer)
+			stopifnot(min(layer) > 0 & max(layer) <= nl)
+		} else {
+			layer <- match(layer, names(x))
+			if (any(is.na(layer))) error("extract", "names in argument 'layer' do not match names(x)")
+		}
+		useLyr <- TRUE
+	}
+
 	#f <- function(i) if(length(i)==0) { NA } else { i }
 	#e <- rapply(e, f, how="replace")
 	cn <- names(x)
@@ -126,7 +148,7 @@ function(x, y, fun=NULL, method="simple", list=FALSE, factors=TRUE, cells=FALSE,
 		if (weights || exact) {
 			if (hasfun) {
 				e <- t(sapply(e, fun, ...))
-				e <- matrix(e, nrow=nrow(y), byrow=TRUE)
+				#e <- matrix(e, nrow=nrow(y), byrow=TRUE)
 				colnames(e) <- cn
 				e <- cbind(ID=1:nrow(e), e)
 			}
@@ -136,7 +158,7 @@ function(x, y, fun=NULL, method="simple", list=FALSE, factors=TRUE, cells=FALSE,
 
 	e <- x@ptr$extractVectorFlat(y@ptr, touches[1], method, isTRUE(cells[1]), isTRUE(xy[1]), isTRUE(weights[1]), isTRUE(exact[1]))
 	x <- messages(x, "extract")
-	nc <- nlyr(x)
+	nc <- nl
 	if (cells) {
 		cn <- c(cn, "cell")
 		nc <- nc + 1
@@ -156,11 +178,11 @@ function(x, y, fun=NULL, method="simple", list=FALSE, factors=TRUE, cells=FALSE,
 	geo <- geomtype(y)
 	if (geo == "points") {
 		## this was? should be fixed upstream
-		#if (nc == nlyr(x)) {		
-		#	e <- matrix(e, ncol=nc)
-		#} else {
-		e <- matrix(e, ncol=nc)		
-		#}
+		if (nc == nl) {		
+			e <- matrix(e, ncol=nc)
+		} else {
+			e <- matrix(e, ncol=nc, byrow=TRUE)
+		}
 		e <- cbind(1:nrow(e), e)
 	} else {
 		e <- matrix(e, ncol=nc+1, byrow=TRUE)
@@ -171,6 +193,7 @@ function(x, y, fun=NULL, method="simple", list=FALSE, factors=TRUE, cells=FALSE,
 		fun <- match.fun(fun) 
 		e <- data.frame(e)
 		e <- aggregate(e[,-1,drop=FALSE], e[,1,drop=FALSE], fun, ...)
+
 		m <- sapply(e, NCOL)
 		if (any(m > 1)) {
 			e <- do.call(cbind, as.list(e))
@@ -215,6 +238,17 @@ function(x, y, fun=NULL, method="simple", list=FALSE, factors=TRUE, cells=FALSE,
 			}
 		}
 	}
+
+	if (useLyr) {
+		idx <- cbind(e[,1], layer[e[,1]]+1)
+		ee <- cbind(e[,1,drop=FALSE], names(x)[idx[,2]-1], value=e[idx])
+		colnames(ee)[2] <- lyr_name
+		if (ncol(e) > (nl+1)) {
+			e <- cbind(ee, e[,(nl+1):ncol(e), drop=FALSE])
+		} else {
+			e <- ee
+		}
+	}
 	e
 })
 
