@@ -25,7 +25,7 @@ double distance_haversine(double lon1, double lat1, double lon2, double lat2);
 double distance_lonlat(const double &lon1, const double &lat1, const double &lon2, const double &lat2);
 std::vector<double> distance_lonlat(std::vector<double> &lon1, std::vector<double> &lat1, std::vector<double> &lon2, std::vector<double> &lat2) ;
 std::vector<double> distance_lonlat_vd(std::vector<double> &lon1, std::vector<double> &lat1, double lon2, double lat2) ;
-
+double distHaversine(double lon1, double lat1, double lon2, double lat2);
 
 // direction
 double direction_lonlat(double lon1, double lat1, double lon2, double lat2, bool degrees);
@@ -39,11 +39,20 @@ std::vector<double> directionToNearest_plane(std::vector<double> x1, std::vector
 // destination
 std::vector<double> destpoint_lonlat(double longitude, double latitude, double  bearing, double distance);
 
-std::vector<std::vector<double> > destpoint_lonlat(std::vector<double>& longitude, std::vector<double>& latitude, std::vector<double>& bearing, std::vector<double>& distance);
+std::vector<std::vector<double>> destpoint_lonlat(const std::vector<double>& longitude, const std::vector<double>& latitude, const std::vector<double>& bearing, const std::vector<double>& distance);
 
-std::vector<std::vector<double> > destpoint_lonlat(double& longitude, double& latitude, std::vector<double>& bearing, double& distance);
+std::vector<std::vector<double>> destpoint_lonlat(const double& longitude, const double& latitude, const std::vector<double>& bearing, const double& distance, bool wrap=true);
 
 std::vector<double> destpoint_plane(double x, double y, double bearing, double distance);
 std::vector<std::vector<double> > destpoint_plane(std::vector<double>  x, std::vector<double>  y, std::vector<double>  bearing, std::vector<double>  distance);
 
 double toRad(double &deg);
+
+void distanceToNearest_plane(std::vector<double> &d, const std::vector<double> &x1, const  std::vector<double> &y1, const std::vector<double> &x2, const std::vector<double> &y2, const double& lindist);
+void distanceToNearest_lonlat(std::vector<double> &d, const std::vector<double> &lon1, const std::vector<double> &lat1, const std::vector<double> &lon2, const std::vector<double> &lat2);
+
+
+void nearest_lonlat(std::vector<long> &id, std::vector<double> &d, std::vector<double> &nlon, std::vector<double> &nlat, const std::vector<double> &lon1, const std::vector<double> &lat1, const std::vector<double> &lon2, const std::vector<double> &lat2);
+void nearest_lonlat_self(std::vector<long> &id, std::vector<double> &d, std::vector<double> &nlon, std::vector<double> &nlat, const std::vector<double> &lon, const std::vector<double> &lat);
+
+
